|
Optimization for insertdict()
|
|
3
|
298
|
October 5, 2026
|
|
Python 3.11 and Function Call Frequency
|
|
36
|
1430
|
July 20, 2026
|
|
Correct way to use timeit and why its giving me wrong incorrect timings
|
|
4
|
247
|
July 15, 2026
|
|
Can the bytecode optimization code be farmed out to LLVM?
|
|
3
|
409
|
July 13, 2026
|
|
News faster CPython, JIT and 3.14
|
|
28
|
10411
|
June 30, 2026
|
|
BehaviorEnum: an Enum subclass that bundles a value with a callable - stdlib candidate?
|
|
27
|
1406
|
April 6, 2026
|
|
Memory-Efficient Dictionary via Elastic Hashing (Achieving 40%+ RAM savings at high load factors)
|
|
26
|
2089
|
March 21, 2026
|
|
Why did cProfile crash?
|
|
2
|
172
|
February 1, 2026
|
|
Best practice for collecting perf stat counters for pyperformance benchmarks without including harness overhead?
|
|
0
|
205
|
January 20, 2026
|
|
Add zero-copy conversion of `bytearray` to `bytes` by providing `__bytes__()`
|
|
70
|
4802
|
January 15, 2026
|
|
Python 3.15 JIT benchmarks
|
|
3
|
994
|
January 13, 2026
|
|
Guidelines for acceptable performance optimizations?
|
|
6
|
694
|
January 9, 2026
|
|
How did you make such huge performance gains?
|
|
2
|
491
|
December 12, 2025
|
|
Performance regression from using `email.message.Message.get_params()` as replacement of `cgi.parse_header` following PEP 594
|
|
8
|
932
|
September 4, 2025
|
|
Using Clang-CL for Better Performance on Windows on ARM
|
|
12
|
1177
|
July 1, 2025
|
|
Who works on digital sustainability in the Python world?
|
|
21
|
1799
|
June 20, 2025
|
|
Performance of chained operations on numpy arrays
|
|
9
|
496
|
June 11, 2025
|
|
Question about JIT performance improvement
|
|
2
|
393
|
June 7, 2025
|
|
Python // vs. divmod?
|
|
11
|
528
|
May 30, 2025
|
|
Add control flow callbacks for JIT-compiled frameworks
|
|
12
|
679
|
May 13, 2025
|
|
Python 3.14.0a7 - Slow functions when including try-except statement
|
|
1
|
291
|
April 24, 2025
|
|
High-performance Asyncio networking: sockets vs streams vs protocols
|
|
10
|
3029
|
December 23, 2024
|
|
numpy array access
|
|
7
|
1451
|
December 2, 2024
|
|
Enable dictionary constructor to compute values concurrently
|
|
4
|
366
|
December 1, 2024
|
|
Why python in Debian Docker image is faster than official Docker's python image?
|
|
11
|
3555
|
May 23, 2024
|
|
Profiling applications with decorators - how to improve decorator names
|
|
0
|
367
|
March 7, 2024
|
|
Performance of str.encode vs codecs.getwriter
|
|
9
|
730
|
February 14, 2024
|
|
How much memory does using "from xxx import *" use
|
|
9
|
59231
|
January 31, 2024
|
|
Add `key` argument to `tuple.index()`
|
|
18
|
1396
|
January 7, 2024
|
|
Make several attributes stores a SINGLE instruction
|
|
9
|
938
|
January 6, 2024
|